package edu.odu.cs.codeAnnotation;

import static org.junit.Assert.assertEquals;

import org.junit.Test;

public class TestCode2TeX {
    

    @Test
    public void testKeyword() throws Exception {
        assertEquals("\\lstln{}abc \\lstkwd{for} defor\n", Code2TeX.test("abc for defor"));
    }

    @Test
    public void testString() throws Exception {
        assertEquals("\\lstln{}abc \\begin{lststring}\"for\"\\end{lststring} defor\n", Code2TeX.test("abc \"for\" defor"));
    }
    
    @Test
    public void testComments() throws Exception {
        assertEquals("\\lstln{}abc \\begin{lstcomment}/*for*/\\end{lstcomment} defor\n", Code2TeX.test("abc /*for*/ defor"));
        assertEquals("\\lstln{}abc \\begin{lstcomment}//for\\end{lstcomment}\n\\lstln{} defor\n", Code2TeX.test("abc //for\n defor"));
    }
    
    @Test
    public void testPreproc() throws Exception {
        assertEquals("\\lstln{}abc \n\\lstln{}\\begin{lstdirective}#for\\end{lstdirective}\n\\lstln{} defor\n", Code2TeX.test("abc \n#for\n defor"));
    }

    @Test
    public void testDots() throws Exception {
    	assertEquals("\\lstln{}abc\\smvdots{}def\n", Code2TeX.test("abc/*...*/def"));
    	assertEquals("\\lstln{}abc\\smvdots{}def\n", Code2TeX.test("abc//...def"));
    }

    @Test
    public void testCallOuts() throws Exception {
    	assertEquals("\\lstln{}abc\\conum{1}def\n", Code2TeX.test("abc/*co1*/def"));
    	assertEquals("\\lstln{}abc\\conum{2}def\n", Code2TeX.test("abc/**co2*/def"));
    	assertEquals("\\lstln{}abc\\conum{3}def\n", Code2TeX.test("abc/*co3*/def"));
    	assertEquals("\\lstln{}abc\\conum{9}def\n", Code2TeX.test("abc/*co9*/def"));
    }

    @Test
    public void singleLineHighlight() throws Exception {
    	assertEquals("\\lstln{}abc\\hli{def}ghi\n", Code2TeX.test("abc/*+*/def/*-*/ghi"));
    	assertEquals("\\lstln{}abc\\hli{def}ghi\n", Code2TeX.test("abc/*+1*/def/*-1*/ghi"));
    	assertEquals("\\lstln{}abc\\hlii{def}ghi\n", Code2TeX.test("abc/*+2*/def/*-2*/ghi"));
    	assertEquals("\\lstln{}abc\\hliii{def}ghi\n", Code2TeX.test("abc/*+3*/def/*-3*/ghi"));
    }

    @Test
    public void multiLineHighlight() throws Exception {
    	assertEquals("\\lstln{}abc\\hli{d}\n\\lstln{}\\hli{ef}ghi\n", Code2TeX.test("abc/*+*/d\nef/*-*/ghi"));
    	assertEquals("\\lstln{}abc\\hli{d}\n\\lstln{}\\hli{e}\n\\lstln{}\\hli{f}ghi\n", Code2TeX.test("abc/*+1*/d\ne\nf/*-1*/ghi"));
    	assertEquals("\\lstln{}abc\\hlii{def}\n\\lstln{}\\hlii{}ghi\n", Code2TeX.test("abc/*+2*/def\n/*-2*/ghi"));
    	assertEquals("\\lstln{}abc\\hliii{}\n\\lstln{}\\hliii{def}ghi\n", Code2TeX.test("abc/*+3*/\ndef/*-3*/ghi"));
    }

    
}
